package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.UserFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.Token;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class AuthServiceImpl implements AuthService {
    @Autowired
    private UserFeign userFeign;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private HttpServletRequest request;
    @Override
    public Result authLogin(User user) {
        Result<User> userResult = userFeign.userLogin( user.getUserName() );
        User data = userResult.getData();
        if(StringUtils.isBlank( user.getUserName() )){
            return Result.error(500,"请输入用户名");
        }
        if(StringUtils.isBlank( user.getUserPwd() )){
            return Result.error(500,"请输入密码");
        }
        if (data==null){
            return Result.error(500,"该用户信息不存在");
        }
        if(!user.getUserPwd().equals( data.getUserPwd() )){
            return Result.error(500,"密码不正确");
        }


        String replace = UUID.randomUUID().toString().replace( "-", "" );
        Map<String, Object> map = new HashMap<>();
        map.put( JwtConstants.USER_KEY,replace );
        String token = JwtUtils.createToken( map );
        Token token1 = new Token();
        token1.setToken( token );
        redisTemplate.opsForValue().set( "token:"+replace, JSONObject.toJSONString( data ),60, TimeUnit.MINUTES);
        token1.setTime( "60分钟内有效" );
        return Result.success(token1);
    }

    @Override
    public Result info() {
        String token = request.getHeader( "token" );
        String userKey = JwtUtils.getUserKey( token );
        String s = redisTemplate.opsForValue().get( "token:" + userKey );
        User user = JSONObject.parseObject( s, User.class );
        return Result.success(user);
    }
}
