package com.bwie.room.controller;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.domain.Log;
import com.bwie.common.domain.Mouth;
import com.bwie.common.domain.Room;
import com.bwie.common.domain.User;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.room.service.impl.RoomServiceImpl;
import com.bwie.room.util.OssUtil;
import lombok.val;
import org.apache.ibatis.annotations.Param;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.List;

@RestController
public class RoomController {
    @Autowired
    private RoomServiceImpl roomService;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private HttpServletRequest request;



    @PostMapping("/findRoomList")
    public Result<List<Room>> findRoomList(@RequestBody Room room){
        List<Room> roomList = roomService.findRoomList( room.getRentId(), room.getRoomName(), room.getRoomPrice() );
        return Result.success(roomList);
    }
    @PostMapping("/upload")
    public String upload(@RequestParam MultipartFile file){
        return OssUtil.uploadMultipartFile( file );
    }
    //回显
    @PostMapping("/findById")
    public Result findById(@RequestParam Integer roomId){
        Room byId=roomService.findById(roomId);
        return Result.success(byId);
    }
    //租房
    @PostMapping("/updRentStatusById")
    public Result updRentStatusById(@RequestBody Room room){
        Integer i = roomService.updRentStatusById( room.getRoomId() );
        String token = request.getHeader( "token" );
        String userKey = JwtUtils.getUserKey( token );
        String s = redisTemplate.opsForValue().get( "token:" + userKey );
        User user = JSONObject.parseObject( s, User.class );
        if(i<1){
            return Result.error(500,"您的申请未提交请重试");
        }
        Log log = new Log();
//(0, #{logUsername}, #{logTime}, #{logUserSex}, #{logUserAge},
// #{logRoomName}, #{logRoomRent}, #{logRoomMouth},
// #{logRoomRent}, 0, #{logText});
        log.setLogUsername( user.getUserName() );
        log.setLogUserSex( user.getUserSex() );
        log.setLogUserAge( user.getUserAge() );
        log.setLogRoomName( room.getRoomName() );
        Integer rentId = room.getRentId();
        String rentName="";
        if(rentId==1){
            rentName = "整租";
        }
        if(rentId==2){
            rentName = "单间";
        }
        if(rentId==3){
            rentName = "合租";
        }
        //类型
        log.setLogRoomRent( rentName );
        //住多久
        Integer monthId = room.getMonthId();
        //月租金
        Integer roomPrice = room.getRoomPrice();
        //总价钱
        log.setLogRoomPrice(roomPrice);
        roomService.addLog( log );
        roomService.stop( user.getUserId() );
        return Result.success();
    }
    //签约时长下拉框
    @PostMapping("/mouthXlk")
    public Result<List<Mouth>> mouthXlk(){
        List<Mouth> mouths = roomService.mouthList();
        return Result.success(mouths);
    }
}
